@@ -16,8 +16,8 @@ supported_games_dict = {
     "BuggyBoy": 1
 }
 
-DLL32 = "/DLL/32Bit/"
-DLL64 = "/DLL/64Bit/"
+DLL32 = "DLL/32Bit/"
+DLL64 = "DLL/64Bit/"
 
 def _load_cdll(path, name):
     relPath = ""
@@ -27,11 +27,11 @@ def _load_cdll(path, name):
         ext_suffix = ".dylib"
     elif sys.platform.startswith("win"):
         if(sizeof(c_void_p) == 4):
-            os.add_dll_directory(os.path.dirname(__file__) + DLL32)
+            os.add_dll_directory(os.path.dirname(__file__) + "/" + DLL32)
             ext_suffix = "-32.dll"
             relPath = DLL32
         else:
-            os.add_dll_directory(os.path.dirname(__file__) + DLL64)
+            os.add_dll_directory(os.path.dirname(__file__) + "/" + DLL64)
             ext_suffix = "-64.dll"
             relPath = DLL64
     else:
